from argparse import ArgumentParser
from collections import defaultdict
from pathlib import Path

from humanize import naturalsize
from tabulate import tabulate


def walk(top: Path, sizes=None):
    if sizes is None:
        sizes = defaultdict(int)
    try:
        size = top.stat().st_size
        sizes[top] += size
        for parent in top.parents:
            sizes[parent] += size
        if top.is_dir():
            for child in top.iterdir():
                walk(child, sizes)
    except FileNotFoundError:
        pass
    return sizes


def main():
    parser = ArgumentParser()
    parser.add_argument("top", type=Path, nargs="?", default=Path("."))
    parser.add_argument("-f", "--tablefmt", default="plain")
    args = parser.parse_args()

    sizes = walk(args.top)
    table = []
    for path, size in sorted(sizes.items(), key=lambda v: (v[1], v[0])):
        if args.top in path.parents or args.top == path:
            end = "/" if path.is_dir() and not path.as_posix().endswith("/") else ""
            table.append(
                (*naturalsize(size, binary=True).split(), path.as_posix() + end)
            )

    print(tabulate(table, tablefmt=args.tablefmt))



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['dude']
install_requires = \
['humanize>=3.1.0,<4.0.0', 'tabulate>=0.8.7,<0.9.0']

entry_points = \
{'console_scripts': ['dude = dude:main']}

setup_kwargs = {
    'name': 'dude',
    'version': '0.1.0',
    'description': 'tool similar to du but a little fancier i guess',
    'long_description': None,
    'author': 'Andrew Herbig',
    'author_email': 'notandrewherbig@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/andrew12/dude',
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
